@@ -213,6 +213,7 @@ static void mode_selection_applet_class_finalize (ModeSelectionAppletClass *klas
 static void mode_selection_applet_init (ModeSelectionApplet *plugin)
 {
 	gchar *phone_state;
+	GtkWidget *image = NULL;
 	ModeSelectionAppletPrivate *priv = MODE_SELECTION_APPLET_GET_PRIVATE (plugin);
 
 	priv->dbus_conn = dbus_g_bus_get (DBUS_BUS_SYSTEM, NULL);
@@ -226,6 +227,16 @@ static void mode_selection_applet_init (ModeSelectionApplet *plugin)
 
 	priv->status_button = hildon_button_new_with_text (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH, HILDON_BUTTON_ARRANGEMENT_VERTICAL, g_dgettext_localised_or_english ("osso-connectivity-ui", "conn_fi_phone_network_mode", "Network mode"), NULL);
 	hildon_button_set_style (HILDON_BUTTON (priv->status_button), HILDON_BUTTON_STYLE_PICKER);
+	if (gtk_icon_theme_has_icon (gtk_icon_theme_get_default (), "3g2g-applet-signal"))
+		image = gtk_image_new_from_icon_name ("3g2g-applet-signal", HILDON_ICON_SIZE_FINGER);
+	else
+	{
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale ("/usr/share/icons/hicolor/48x48/hildon/3g2g-applet-signal.png", 48, 48, TRUE, NULL);
+		image = gtk_image_new_from_pixbuf (pixbuf);
+		g_object_unref (pixbuf);
+	}
+	hildon_button_set_image (HILDON_BUTTON (priv->status_button), image);
+
 	hildon_button_set_alignment (HILDON_BUTTON (priv->status_button), 0, 0, 0, 0);
 
 	g_signal_connect (G_OBJECT (priv->status_button), "clicked", G_CALLBACK (mode_selection_applet_on_button_clicked), plugin);
